WatchObject

Struct WatchObject 

pub struct WatchObject {
    pub enable: bool,
    pub json: bool,
    pub nmea: bool,
    pub raw: Option<u32>,
    pub scaled: bool,
    pub split24: bool,
    pub pps: bool,
    pub device: Option<String>,
    pub remote: Option<String>,
}
Information about watcher mode parameters.

Fields

enable: bool

Enable (true) or disable (false) watcher mode. Default is true.

json: bool

Enable (true) or disable (false) dumping of JSON reports. Default is false.

nmea: bool

Enable (true) or disable (false) dumping of binary packets as pseudo-NMEA. Default is false.

raw: Option<u32>

Controls ‘raw’ mode. When this attribute is set to 1 for a channel, gpsd reports the unprocessed NMEA or AIVDM data stream from whatever device is attached. Binary GPS packets are hex-dumped. RTCM2 and RTCM3 packets are not dumped in raw mode. When this attribute is set to 2 for a channel that processes binary data, gpsd reports the received data verbatim without hex-dumping.

scaled: bool

If true, apply scaling divisors to output before dumping; default is false.

split24: bool

If true, aggregate AIS type24 sentence parts. If false, report each part as a separate JSON object, leaving the client to match MMSIs and aggregate. Default is false. Applies only to AIS reports.

pps: bool

If true, emit the TOFF JSON message on each cycle and a PPS JSON message when the device issues 1PPS. Default is false.

device: Option<String>

If present, enable watching only of the specified device rather than all devices. Useful with raw and NMEA modes in which device responses aren’t tagged. Has no effect when used with enable:false.

remote: Option<String>

URL of the remote daemon reporting the watch set. If empty, this is a WATCH response from the local daemon.